==> igniteui-react-charts-16.6.8.tgz: package/ES2015/ScatterPolylineSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { ShapeSeriesBase } from "./ShapeSeriesBase";
import { StyleSelector } from "./StyleSelector";
import { DependencyProperty } from "igniteui-react-core/ES2015/DependencyProperty";
import { Style } from "igniteui-react-core/ES2015/Style";
import { Type, markType, typeCast } from "igniteui-react-core/ES2015/type";
import { ShapeSeriesViewBase } from "./ShapeSeriesViewBase";
import { PropertyMetadata } from "igniteui-react-core/ES2015/PropertyMetadata";
import { Path } from "igniteui-react-core/ES2015/Path";
import { stringIsNullOrEmpty } from "igniteui-react-core/ES2015/string";
/**
 * @hidden
 */
export class ScatterPolylineSeries extends ShapeSeriesBase {
    constructor() {
        super();
        this.ab = ScatterPolylineSeries.$;
    }
    bf() {
        return new ScatterPolylineSeriesView(this);
    }
    im(a) {
        super.im(a);
        this.m3 = a;
    }
    get_l8() {
        return false;
    }
    is(a, b, c, d) {
        super.is(a, b, c, d);
        switch (b) {
            case ScatterPolylineSeries.$$p[0]:
                this.m3.cn(this.m9);
                this.i6(false);
                this.ic();
                break;
            case ScatterPolylineSeries.$$p[1]:
                this.m3.co(this.m4);
                this.i6(false);
                this.ic();
                break;
        }
    }
    ms(a) {
        let b = a;
        b.cn(this.m9);
        b.co(this.m4);
        super.ms(a);
    }
    ar(a, b) {
        let c = this.m3.cs(a, b, true);
        if (c != null) {
            return c.dataContext;
        }
        return super.ar(a, b);
    }
}
ScatterPolylineSeries.$t = markType(ScatterPolylineSeries, 'ScatterPolylineSeries', ShapeSeriesBase.$);
Type.dep(DependencyProperty, PropertyMetadata, ScatterPolylineSeries, 'raisePropertyChanged', ['ShapeStyle:m9:m7', [Style.$, null], 'ShapeStyleSelector:m4:m8', [StyleSelector.$, null]]);
/**
 * @hidden
 */
export class ScatterPolylineSeriesView extends ShapeSeriesViewBase {
    constructor(a) {
        super(a);
    }
    cu(a, b) {
        return this.cv(a, b, false);
    }
    cc(a, b) {
        super.cc(a, b);
        ShapeSeriesViewBase.cb(this, a, b);
    }
    ca(a, b) {
        let c = typeCast(Path.$, a);
        if (c == null) {
            return;
        }
        c.aj = b;
    }
    bb(a, b) {
        super.bb(a, b);
        let c = a;
        c._fill = null;
    }
    bc(a, b) {
        super.bc(a, b);
        let c = a;
        c._fill = null;
    }
    b2(a) {
        return a.width >= this.by.mh || a.height >= this.by.mh;
    }
    getDefaultTooltipTemplate() {
        let a = "<div class='ui-chart-default-tooltip-content'><span";
        let b = this.e.a0.a$q(this.e);
        if (!stringIsNullOrEmpty(b)) {
            a += " style='color:" + b + "'";
        }
        a += ">" + this.by.fs + "</span><br/>";
        a += "</div>";
        return a;
    }
}
ScatterPolylineSeriesView.$t = markType(ScatterPolylineSeriesView, 'ScatterPolylineSeriesView', ShapeSeriesViewBase.$);

==> igniteui-react-charts-16.11.1.tgz: package/ES2015/ScatterPolylineSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { ShapeSeriesBase } from "./ShapeSeriesBase";
import { StyleSelector } from "./StyleSelector";
import { DependencyProperty } from "igniteui-react-core/ES2015/DependencyProperty";
import { Style } from "igniteui-react-core/ES2015/Style";
import { Type, markType, typeCast } from "igniteui-react-core/ES2015/type";
import { ShapeSeriesViewBase } from "./ShapeSeriesViewBase";
import { PropertyMetadata } from "igniteui-react-core/ES2015/PropertyMetadata";
import { Path } from "igniteui-react-core/ES2015/Path";
import { stringIsNullOrEmpty } from "igniteui-react-core/ES2015/string";
/**
 * @hidden
 */
export class ScatterPolylineSeries extends ShapeSeriesBase {
    constructor() {
        super();
        this.ab = ScatterPolylineSeries.$;
    }
    bf() {
        return new ScatterPolylineSeriesView(this);
    }
    iu(a) {
        super.iu(a);
        this.na = a;
    }
    get_mf() {
        return false;
    }
    iz(a, b, c, d) {
        super.iz(a, b, c, d);
        switch (b) {
            case ScatterPolylineSeries.$$p[0]:
                this.na.cn(this.ng);
                this.jd(false);
                this.ik();
                break;
            case ScatterPolylineSeries.$$p[1]:
                this.na.co(this.nb);
                this.jd(false);
                this.ik();
                break;
        }
    }
    mz(a) {
        let b = a;
        b.cn(this.ng);
        b.co(this.nb);
        super.mz(a);
    }
    ar(a, b) {
        let c = this.na.cs(a, b, true);
        if (c != null) {
            return c.dataContext;
        }
        return super.ar(a, b);
    }
}
ScatterPolylineSeries.$t = markType(ScatterPolylineSeries, 'ScatterPolylineSeries', ShapeSeriesBase.$);
Type.dep(DependencyProperty, PropertyMetadata, ScatterPolylineSeries, 'raisePropertyChanged', ['ShapeStyle:ng:ne', [Style.$, null], 'ShapeStyleSelector:nb:nf', [StyleSelector.$, null]]);
/**
 * @hidden
 */
export class ScatterPolylineSeriesView extends ShapeSeriesViewBase {
    constructor(a) {
        super(a);
    }
    cu(a, b) {
        return this.cv(a, b, false);
    }
    cc(a, b) {
        super.cc(a, b);
        ShapeSeriesViewBase.cb(this, a, b);
    }
    ca(a, b) {
        let c = typeCast(Path.$, a);
        if (c == null) {
            return;
        }
        c.ak = b;
    }
    bb(a, b) {
        super.bb(a, b);
        let c = a;
        c._fill = null;
    }
    bc(a, b) {
        super.bc(a, b);
        let c = a;
        c._fill = null;
    }
    b2(a) {
        return a.width >= this.by.mo || a.height >= this.by.mo;
    }
    getDefaultTooltipTemplate() {
        let a = "<div class='ui-chart-default-tooltip-content'><span";
        let b = this.e.a0.a$q(this.e);
        if (!stringIsNullOrEmpty(b)) {
            a += " style='color:" + b + "'";
        }
        a += ">" + this.by.fx + "</span><br/>";
        a += "</div>";
        return a;
    }
}
ScatterPolylineSeriesView.$t = markType(ScatterPolylineSeriesView, 'ScatterPolylineSeriesView', ShapeSeriesViewBase.$);
